@@ -27,3 +27,11 @@ def celsius_from_fahrenheit(f):
 
 def fahrenheit_from_celsius(c):
     return c * (9 / 5) + 32
+
+
+def mps_to_kph(v):
+    return v / (1000 / 3600)
+
+
+def kph_to_mps(v):
+    return v * (1000 / 3600)
